[GRASS-SVN] r63780 - in grass/trunk: general/g.parser lib/gis

svn_grass at osgeo.org svn_grass at osgeo.org
Sat Dec 27 09:51:44 PST 2014


Author: wenzeslaus
Date: 2014-12-27 09:51:44 -0800 (Sat, 27 Dec 2014)
New Revision: 63780

Modified:
   grass/trunk/general/g.parser/g.parser.html
   grass/trunk/lib/gis/parser.c
Log:
rename --rest-description to --rst-description

 * avoids possible confusion with REST in this context
 * GRASS GIS should generally prefer reStructuredText (full name) or rst (file extension)
 * main Docutils page (http://docutils.sourceforge.net/rst.html) is not consistent when using both reST and ReST
 * Sphinx (http://sphinx-doc.org/rest.html) is consistent in using reST (but does not solve the problem with REST when everything is lowercased)
 * Wikipedia uses reST and says: reStructuredText is sometimes abbreviated as RST, ReST, or reST. This can create confusion with Representational State Transfer (REST), an unrelated technology.

 * changing only the API and documentation
 * no changes to the source code, filenames, or scripts made
 * the other changes would be good but are not pressing because they don't change API


Modified: grass/trunk/general/g.parser/g.parser.html
===================================================================
--- grass/trunk/general/g.parser/g.parser.html	2014-12-27 13:30:46 UTC (rev 63779)
+++ grass/trunk/general/g.parser/g.parser.html	2014-12-27 17:51:44 UTC (rev 63780)
@@ -197,15 +197,19 @@
 v.in.db --wps-process-description
 </pre></div>
 
-<h2>reStructuredText (REST)</h2>
+<h2>reStructuredText</h2>
 
-The flag <b>--rest-description</b> added to a GRASS command
-generates a related help page template in reStructuredText. Example:
+The flag <b>--rst-description</b> added to a GRASS command
+generates module interface description in reStructuredText, a lightweight
+markup language. Example:
 
 <div class="code"><pre>
-v.in.db --rest-description
+v.in.db --rst-description
 </pre></div>
 
+reStructuredText is sometimes abbreviated as reST, ReST, or RST.
+The commonly used file extension is <tt>.rst</tt>.
+Don't be confused with Representational State Transfer (REST) technology.
 
 <h2>TRANSLATION</h2>
 

Modified: grass/trunk/lib/gis/parser.c
===================================================================
--- grass/trunk/lib/gis/parser.c	2014-12-27 13:30:46 UTC (rev 63779)
+++ grass/trunk/lib/gis/parser.c	2014-12-27 17:51:44 UTC (rev 63780)
@@ -469,13 +469,13 @@
 	    G__usage_html();
 	    exit(EXIT_SUCCESS);
 	}
-	
-	/* If first arg is "--rest-description" then print out
-        * a ReST description of the task */
-	if (strcmp(argv[1], "--rest-description") == 0) {
+
+	/* If first arg is "--rst-description" then print out
+	 * a reStructuredText description of the task */
+	if (strcmp(argv[1], "--rst-description") == 0) {
 	    G__usage_rest();
 	    exit(EXIT_SUCCESS);
-	}	
+	}
 
 	/* If first arg is "--wps-process-description" then print out
 	 * the wps process description of the task */



More information about the grass-commit mailing list